/*
 * gui_misc.h: misc gui routines
 * Copyright (C) 2002-2004 Saulius Menkevicius
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef GUI_MISC_H__
#define GUI_MISC_H__

#include "user.h"

#define GUI_STOCK_LOGO		"vqcc-logo"
#define GUI_STOCK_LOGO_NO_Q	"vqcc-logo-no-q"
#define GUI_STOCK_STATUS	"vqcc-status"
#define GUI_STOCK_STATUS_INACTIVE "vqcc-status-inactive"
#define GUI_STOCK_CHANNEL	"vqcc-channel"
#define GUI_STOCK_CHANNEL_INACTIVE "vqcc-channel-inactive"
#define GUI_STOCK_OPEN_CHAT	GTK_STOCK_JUSTIFY_LEFT
#define GUI_STOCK_CLOSE_CHAT	GTK_STOCK_CLOSE
#define GUI_STOCK_SET_TOPIC	GTK_STOCK_BOLD
#define GUI_STOCK_SEND_MESSAGE	"vqcc-send-message"
#define GUI_STOCK_REPLY_MESSAGE	"vqcc-reply-message"
#define	GUI_STOCK_QUOTE_MESSAGE	"vqcc-quote-message"
#define GUI_STOCK_IGNORE	GTK_STOCK_STOP
#define GUI_STOCK_UNIGNORE	GTK_STOCK_STOP
#define GUI_STOCK_USER_DEAD	"vqcc-user-dead"
#define GUI_STOCK_USER_NORMAL	"vqcc-user-normal"
#define GUI_STOCK_USER_NORMAL_GREY "vqcc-user-normal-grey"
#define GUI_STOCK_USER_AWAY	"vqcc-user-away"
#define GUI_STOCK_USER_AWAY_GREY "vqcc-user-away-grey"
#define GUI_STOCK_USER_DND	"vqcc-user-dnd"
#define GUI_STOCK_USER_DND_GREY	"vqcc-user-dnd-grey"
#define GUI_STOCK_USER_OFFLINE	"vqcc-user-offline"
#define GUI_STOCK_USER_OFFLINE_GREY "vqcc-user-offline-grey"
#define GUI_STOCK_USER_INVISIBLE "vqcc-user-invisible"
#define GUI_STOCK_USER_INVISIBLE_GREY "vqcc-user-invisible-grey"

enum gui_response_enum {
	GUI_RESPONSE_SAVE,
	GUI_RESPONSE_SEND,
	GUI_RESPONSE_REPLY,
	GUI_RESPONSE_QUOTE
};

void gui_misc_init();
void gui_misc_destroy();

void gui_misc_set_icon_for(GtkWindow *);

const gchar * util_user_state_stock(enum user_mode_enum mode, gboolean active);

/*
 * widget factories
 */
typedef void (*util_option_changed_cb)(gint, gpointer);
GtkWidget * util_user_mode_option(util_option_changed_cb, gpointer);
GtkWidget * util_net_type_option(util_option_changed_cb, gpointer);

void set_user_mode_option(GtkWidget *, enum user_mode_enum);
enum user_mode_enum get_user_mode_option(GtkWidget *);

GtkWidget * misc_pix_button(
	const char * label,
	const gchar * pix_stock_id,
	GCallback click_cb,
	gpointer click_cb_param);

/* popup menu factory
 * ------------------ */
struct misc_menu_info_struct {
		/* name must be NULL in order to sign end of list */
		/*  or, "---", if one wants a separator */
	const char *		name;
	const gchar *		pix_stock_id;
	gboolean		enabled;
	enum app_event_enum	event;
	gpointer		event_param;
};

void misc_popup_menu(
	struct misc_menu_info_struct * menu_descr,
	guint32 event_time_stamp, /* timestamp of event which popupp'ed menu */
	guint event_button);      /* which button popupp'ed menu */

#endif	/* #ifndef GUI_MISC_H__ */

