/*
 * prefs.h: configuration management routines
 * Copyright (C) 2002-2004 Saulius Menkevicius
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef PREFS_H__
#define PREFS_H__

enum config_enum {
	CFG_AUTO_SAVE,		/* save on exit?				*/
	CFG_NICKNAME,		/* user nickname				*/
	CFG_USER_LIST_REFRESH,	/* user list refresh interval (in secs)		*/
	CFG_MODE,		/* normal/away/dnd/offline			*/
	CFG_NET_TYPE,		/* network type (CFG_NET_xxx)			*/
	CFG_NET_PORT,		/* broadcast port				*/
	PREF_NET_CONFIGURED,	/* TRUE, if network already configured		*/
	CFG_LOG_NET,	/* log network events (msg sends/recv/info/etc	*/
	CFG_REPLY_INFO,	/* do respond to info requests			*/
	CFG_MSG_WINDOW,	/* show messages in popup windows (or just on log)*/
	CFG_MAX_MSG,	/* max number of popup message to show on screen*/
	CFG_CHANNEL_ST,	/* insert time before channel text lines	*/
	CFG_PRIVATE_ST,	/* insert time before private chat text lines	*/
	CFG_STATUS_ST,	/* show time before status text lines		*/
	CFG_AUTO_AWAY,	/* go to away after some time of inactivity	*/
	CFG_AUTO_OFFLINE,/* go to offline mode -"-			*/
	CFG_NET_MASK1,			/* broadcast network mask #1				*/
	CFG_NET_MASK2,			/* -=- #2						*/
	CFG_KEEP_UNREPLIED_USERS,	/* keep users that appear as missing on the list	*/
	CFG_CHANNEL_GREET,/* notify channels of our presence		*/
	CFG_LOG_CURRENT,/* show messages in current tab as well		*/
	CFG_TRAY_ICON,	/* enable system tray (notification area) icon	*/
	CFG_NOTEBOOK_POS,	/* where to place notebook tabs		*/
	CFG_POPUP_TIMEOUT,	/* ms's to wait to show up a popup		*/
	CFG_KEEP_WND_SIZE,	/* whether to save & restore window size	*/
	CFG_WND_SIZE,		/* size of the main window (\d+x\d+)		*/
	CFG_PRESENT_ON_PRIVATE,	/* popup/show main window when someone opens private chat */
	CFG_TRAY_TRIGGERS,	/* events that would make the systray to blink */
	CFG_TRAY_HIDE_ON_STARTUP, /* hide main window on startup, when tray is enabled */
	CFG_TRAY_TOOLTIP_LINES,	/* max lines to show on the tray tooltip	*/
	CFG_WND_TITLE_MAX_LEN,	/* max length of the topic on the app title bar	*/
	CFG_NET_ENCODING,	/* encoding charset for network messages ("" - system/locale encoding) */
	CFG_MOTD,		/* info message text (message-of-the-day)	*/
	CFG_MOTD_AWAY,		/* message of the day for idle state (AWAY/OFFLINE) */
	PREF_IGNORE_MASS_MSG,	/* ignore mass messages */
	PREF_PERSISTENT_CHANNELS, /* list of persistent channels: "#chan1#chan2....#chanX" */
	CFG_NUM
};

void config_register(int, char **, char **);

gboolean prefs_are_saved();	/* .. if the preferences were saved after last change */

void prefs_set(enum config_enum, ...);

unsigned int config_get_i(enum config_enum);
#define prefs_int(pref) config_get_i(pref)
const char * config_get_s(enum config_enum);
#define prefs_str(pref) config_get_s(pref)

gboolean config_is_ignored(const char *);
void config_ignore_add(const char *);
void config_ignore_remove(const char *);
void config_ignore_remove_all();
GList * config_ignore_list();

#endif /* #ifndef PREFS_H__ */

