/*
 * sess.h: session management
 * Copyright (C) 2002,2003 Saulius Menkevicius
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef SESS_H__
#define SESS_H__

enum session_text_type {
	SESSTEXT_NORMAL,
	SESSTEXT_NOTIFY,
	SESSTEXT_ERROR,
	SESSTEXT_JOIN,
	SESSTEXT_LEAVE,
	SESSTEXT_MY_TEXT,
	SESSTEXT_MY_ME,
	SESSTEXT_THEIR_TEXT,
	SESSTEXT_THEIR_ME,
	SESSTEXT_TOPIC
};

enum session_type {
	SESSTYPE_STATUS,
	SESSTYPE_CHANNEL,
	SESSTYPE_PRIVATE
};

void sess_register();

typedef void * sess_id;
typedef void (*sess_enum_cb)(sess_id, enum session_type,
				const char *, void *, void *);

sess_id sess_new(
	enum session_type type, const char *name,
	gboolean closeable, void *uid);
void sess_delete(sess_id);
gpointer sess_find(enum session_type type, const char * name);
gpointer sess_find_private_by_user(gpointer user_id);
void sess_write(sess_id, enum session_text_type, const char * fmt, ...);
gpointer sess_current();
enum session_type sess_type(gpointer);
const gchar * sess_name(gpointer);
const gchar * sess_topic(gpointer);
gboolean sess_topic_readonly(gpointer);
void sess_switch_to(sess_id);
void sess_enumerate(sess_enum_cb, void *);
GString *sess_make_channel_list();

#endif /* #ifndef SESS_H__ */

